#
# spec file for package libstfl
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
Name:           libstfl
Version:        0.24
Release:        4.2
Summary:        Structured Terminal Forms Library
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://www.clifford.at/stfl/
Source:         http://www.clifford.at/stfl/stfl-%{version}.tar.gz
Source99:       libstfl-rpmlintrc
Patch1:         stfl-optflags.patch
Patch2:         stfl-ncurses.patch
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig

%description
STFL is a library which implements a curses-based widget set for text
terminals. The STFL API can be used from C, SPL, Python, Perl and Ruby.

%package -n libstfl%{sover}
Summary:        Structured Terminal Forms Library
Group:          System/Libraries

%description -n libstfl%{sover}
STFL is a library which implements a curses-based widget set for text
terminals. The STFL API can be used from C, SPL, Python, Perl and Ruby.

A special language (the Structured Terminal Forms Language) is used to
describe STFL GUIs.

%package -n libstfl-devel
Summary:        Structured Terminal Forms Library
Group:          Development/Libraries/C and C++
Requires:       libstfl%{sover} = %{version}
Requires:       ncurses-devel

%description -n libstfl-devel
STFL is a library which implements a curses-based widget set for text
terminals. The STFL API can be used from C, SPL, Python, Perl and Ruby.
The API has only 14 function calls and generic SWIG bindings exist
already for porting STFL to other scripting languages.

A special language (the Structured Terminal Forms Language) is used to
describe STFL GUIs.

%prep
%autosetup -p0 -n "stfl-%{version}"

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
make %{?_smp_mflags} \
	CC="gcc" \
	OPTFLAGS="%{optflags}"\
	FOUND_SPL=0 \
	FOUND_SWIG=0 \
	FOUND_RUBY=0 \
	FOUND_PERL=0 \
	FOUND_PYTHON=0

%install
%make_install \
	libdir="%{_lib}" \
	prefix="%{_prefix}"

[ -e "%{buildroot}%{_libdir}/libstfl.so.%{sover}" ] || {
    pushd "%{buildroot}%{_libdir}/"
    ln -s libstfl.so.*.* libstfl.so.%{sover}
    popd
}

%post   -n libstfl%{sover} -p /sbin/ldconfig
%postun -n libstfl%{sover} -p /sbin/ldconfig

%files -n libstfl%{sover}
%license COPYING
%doc README
%{_libdir}/libstfl.so.%{sover}
%{_libdir}/libstfl.so.%{sover}.*

%files -n libstfl-devel
%{_includedir}/stfl.h
%{_libdir}/libstfl.so
%{_libdir}/libstfl.a
%{_libdir}/pkgconfig/stfl.pc

%changelog
* Fri Mar  1 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
* Tue Feb 20 2018 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use.
- Fix RPM groups. Ensure neutrality of description.
* Sun Feb 18 2018 avindra@opensuse.org
- update to 0.24
  * increased table MAX_ROWS and MAX_COLS
  * Added "process" variable
  * Added stfl_redraw API
  * Added example2
  * Fixed updating of "pos_name" in list widget
  * Added stfl_text() function
  * removed unimplemented stfl_lookup() function
  * Fixed compiler warning in wt_list.c
  * cosmetic changes in parser.c
- cleanup spec file with spec-cleaner
- rebase stfl-optflags.patch
  * version number removed from context for better reusability
* Wed May 13 2015 mpluskal@suse.com
- Update to 0.23
  * no upstream changelog provided
- Cleanup spec file with spec-cleaner
* Fri Mar  2 2012 cfarrell@suse.com
- license update: LGPL-3.0+
  No indication of LGPL-3.0 (only) files. See README also
* Tue Jan 31 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Thu Jun 24 2010 pascal.bleser@opensuse.org
- update to 0.21
- changed spec file as libstfl now also ships a shared library
* Thu Dec 10 2009 pascal.bleser@opensuse.org
- update to 0.20
* Thu Aug 21 2008 guru@unixtech.be
- new package
